@@ -81,11 +81,39 @@ jsonb_id_array_2_int_array: Final = (
     f" IMMUTABLE;")
 
 
+bigint_array_2_id_array: Final = (
+    f" CREATE OR REPLACE FUNCTION "
+    f" {CFn.bigint_array_2_id_array} ("
+    f" IN _input BIGINT[], "
+    f" OUT _result TEXT[]"
+    f" ) "
+    f" AS"
+    f" $$"
+    f" DECLARE"
+    f"   _text_id   BIGINT;"
+    f" BEGIN "
+    f"  _result := ARRAY[]::TEXT[];"
+    f"  IF _input IS NULL THEN"
+    f"      RETURN;"
+    f"  END IF;"
+    f""
+    f" FOREACH _text_id IN ARRAY _input "
+    f" LOOP "
+    f"   _result := _result || bigint_2_id(_text_id); "
+    f" END LOOP;"
+    f""
+    f" END;"
+    f" $$ "
+    f" LANGUAGE PlPgSql "
+    f" ;")
+
 def insert_util_fn__id(conn):
     insert_function(bigint_2_id, CFn.bigint_2_id, conn)
     insert_function(int_2_id, CFn.int_2_id, conn)
     insert_function(id_2_bigint, CFn.id_2_bigint, conn)
     insert_function(id_2_int, CFn.id_2_int, conn)
 
+    insert_function(bigint_array_2_id_array, CFn.bigint_array_2_id_array, conn)
+
     insert_function(jsonb_id_array_2_bigint_array, CFn.jsonb_id_array_2_bigint_array, conn)
     insert_function(jsonb_id_array_2_int_array, CFn.jsonb_id_array_2_int_array, conn)
